package com.ynet.life.net.ftp.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.net.ftp.FtpService;
import java.io.File;
import java.io.IOException;
import org.apache.commons.net.ftp.FTPClient;

/* loaded from: com_ynet_life_net_ftp_action.jar:com/ynet/life/net/ftp/action/FtpDownloadAction.class */
public class FtpDownloadAction extends LifeAction {
    private String ftpFilePathField;
    private String ftpFileNameField;
    private String localFilePathField;
    private boolean binaryFile;

    public String execute(Context context) throws GENEException {
        String filePath = (String) context.getDataValue(this.localFilePathField);
        String ftpFilePath = (String) context.getDataValue(this.ftpFilePathField);
        String ftpFileName = (String) context.getDataValue(this.ftpFileNameField);
        if (!new File(filePath).isDirectory()) {
            LifeFile.makeMultiDirectory(filePath);
            if (!new File(filePath).isDirectory()) {
                Trace.logError("LifeFTP", "创建本地文件夹[" + filePath + "]失败");
                throw new TranFailException("EBLN0000", "创建本地文件夹[" + filePath + "]失败");
            }
        }
        FtpService ftpService = (FtpService) context.getService("FtpService");
        if (ftpService == null) {
            Trace.logError("LifeFTP", "FTP服务[FtpService]未定义");
            throw new TranFailException("EBLN0000", "FTP服务[FtpService]未定义");
        }
        FTPClient ftpClient = null;
        try {
            ftpClient = ftpService.initConnection();
            ftpService.setTransferMode(ftpClient, this.binaryFile);
            ftpService.changeWorkingDirectory(ftpClient, ftpFilePath);
            ftpService.downloadFile(ftpClient, ftpFileName, String.valueOf(filePath) + ftpFileName);
            if (ftpClient != null) {
                try {
                    ftpClient.logout();
                    return "0";
                } catch (IOException ex) {
                    Trace.logWarning("LifeFTP", "FTP对象关闭异常", ex);
                    return "0";
                }
            }
            return "0";
        } catch (Throwable th) {
            if (ftpClient != null) {
                try {
                    ftpClient.logout();
                } catch (IOException ex2) {
                    Trace.logWarning("LifeFTP", "FTP对象关闭异常", ex2);
                }
            }
            throw th;
        }
    }

    public void setFtpFilePathField(String ftpFilePathField) {
        this.ftpFilePathField = ftpFilePathField;
    }

    public void setFtpFileNameField(String ftpFileNameField) {
        this.ftpFileNameField = ftpFileNameField;
    }

    public void setLocalFilePathField(String localFilePathField) {
        this.localFilePathField = localFilePathField;
    }

    public void setBinaryFile(boolean binaryFile) {
        this.binaryFile = binaryFile;
    }
}
